# coding: utf-8

# flake8: noqa

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AiAssistantServiceApi",
    "DataTableServiceApi",
    "DatasetServiceApi",
    "ExportJobServiceApi",
    "RecipeServiceApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AddDatasetDataTableNodeRequest",
    "AddDatasetNodeRequest",
    "AddDatasetRecipeNodeRequest",
    "ConnectionDetails",
    "ConversationIdResponse",
    "ConversationMessageResponse",
    "ConversationResponse",
    "CreateDataTableRequest",
    "CreateDatasetRequest",
    "CreateDatasetVersionRequest",
    "CreateRecipeRequest",
    "CreateRecipeVersionRequest",
    "DataTableResponse",
    "DataTablesResponse",
    "DataVersionResponse",
    "DatasetDataTableNodeResponse",
    "DatasetEdgeResponse",
    "DatasetEdgesResponse",
    "DatasetNodeResponse",
    "DatasetNodesResponse",
    "DatasetRecipeNodeResponse",
    "DatasetResponse",
    "DatasetVersionUsage",
    "DatasetsResponse",
    "ExecuteRecipeRequest",
    "ExportPartResultPairResponse",
    "ExportS3JobStatusResponse",
    "ExportS3PartJobStatusResponse",
    "ExportS3PartRequest",
    "ExportS3PartResponse",
    "ExportS3Request",
    "ExportS3Response",
    "ExportS3StatusResponse",
    "JobError",
    "JobExecution",
    "JobProgress",
    "JobStage",
    "JobStatus",
    "LeanTransformationGraphResponse",
    "ListQuery",
    "Metadata",
    "ProblemDetail",
    "RecipeCodeResponse",
    "RecipeResponse",
    "RecipeStatusResponse",
    "RecipeVersion",
    "RecipeVersionResponse",
    "RecipesResponse",
    "SchemaAnalysisStatusResponse",
    "SinkNodeItem",
    "SinkNodesResponse",
    "SourceNodeDefinition",
    "TransformationGraphResponse",
    "TransformationGraphWrapperResponse",
    "UpdateDataTableRequest",
    "UpdateDatasetDataTableNodeRequest",
    "UpdateDatasetNodeRequest",
    "UpdateDatasetRecipeNodeRequest",
    "UpdateDatasetRequest",
    "UpdateRecipeRequest",
    "UpdateRecipeVersionRequest",
    "User",
    "UserMessageRequest",
]

# import apis into sdk package
from earnix_elevate.clients.data.api.ai_assistant_service_api import (
    AiAssistantServiceApi as AiAssistantServiceApi,
)
from earnix_elevate.clients.data.api.data_table_service_api import (
    DataTableServiceApi as DataTableServiceApi,
)
from earnix_elevate.clients.data.api.dataset_service_api import (
    DatasetServiceApi as DatasetServiceApi,
)
from earnix_elevate.clients.data.api.export_job_service_api import (
    ExportJobServiceApi as ExportJobServiceApi,
)
from earnix_elevate.clients.data.api.recipe_service_api import (
    RecipeServiceApi as RecipeServiceApi,
)

# import ApiClient
from earnix_elevate.clients.data.api_response import ApiResponse as ApiResponse
from earnix_elevate.clients.data.api_client import ApiClient as ApiClient
from earnix_elevate.clients.data.configuration import Configuration as Configuration
from earnix_elevate.clients.data.exceptions import OpenApiException as OpenApiException
from earnix_elevate.clients.data.exceptions import ApiTypeError as ApiTypeError
from earnix_elevate.clients.data.exceptions import ApiValueError as ApiValueError
from earnix_elevate.clients.data.exceptions import ApiKeyError as ApiKeyError
from earnix_elevate.clients.data.exceptions import (
    ApiAttributeError as ApiAttributeError,
)
from earnix_elevate.clients.data.exceptions import ApiException as ApiException

# import models into sdk package
from earnix_elevate.clients.data.models.add_dataset_data_table_node_request import (
    AddDatasetDataTableNodeRequest as AddDatasetDataTableNodeRequest,
)
from earnix_elevate.clients.data.models.add_dataset_node_request import (
    AddDatasetNodeRequest as AddDatasetNodeRequest,
)
from earnix_elevate.clients.data.models.add_dataset_recipe_node_request import (
    AddDatasetRecipeNodeRequest as AddDatasetRecipeNodeRequest,
)
from earnix_elevate.clients.data.models.connection_details import (
    ConnectionDetails as ConnectionDetails,
)
from earnix_elevate.clients.data.models.conversation_id_response import (
    ConversationIdResponse as ConversationIdResponse,
)
from earnix_elevate.clients.data.models.conversation_message_response import (
    ConversationMessageResponse as ConversationMessageResponse,
)
from earnix_elevate.clients.data.models.conversation_response import (
    ConversationResponse as ConversationResponse,
)
from earnix_elevate.clients.data.models.create_data_table_request import (
    CreateDataTableRequest as CreateDataTableRequest,
)
from earnix_elevate.clients.data.models.create_dataset_request import (
    CreateDatasetRequest as CreateDatasetRequest,
)
from earnix_elevate.clients.data.models.create_dataset_version_request import (
    CreateDatasetVersionRequest as CreateDatasetVersionRequest,
)
from earnix_elevate.clients.data.models.create_recipe_request import (
    CreateRecipeRequest as CreateRecipeRequest,
)
from earnix_elevate.clients.data.models.create_recipe_version_request import (
    CreateRecipeVersionRequest as CreateRecipeVersionRequest,
)
from earnix_elevate.clients.data.models.data_table_response import (
    DataTableResponse as DataTableResponse,
)
from earnix_elevate.clients.data.models.data_tables_response import (
    DataTablesResponse as DataTablesResponse,
)
from earnix_elevate.clients.data.models.data_version_response import (
    DataVersionResponse as DataVersionResponse,
)
from earnix_elevate.clients.data.models.dataset_data_table_node_response import (
    DatasetDataTableNodeResponse as DatasetDataTableNodeResponse,
)
from earnix_elevate.clients.data.models.dataset_edge_response import (
    DatasetEdgeResponse as DatasetEdgeResponse,
)
from earnix_elevate.clients.data.models.dataset_edges_response import (
    DatasetEdgesResponse as DatasetEdgesResponse,
)
from earnix_elevate.clients.data.models.dataset_node_response import (
    DatasetNodeResponse as DatasetNodeResponse,
)
from earnix_elevate.clients.data.models.dataset_nodes_response import (
    DatasetNodesResponse as DatasetNodesResponse,
)
from earnix_elevate.clients.data.models.dataset_recipe_node_response import (
    DatasetRecipeNodeResponse as DatasetRecipeNodeResponse,
)
from earnix_elevate.clients.data.models.dataset_response import (
    DatasetResponse as DatasetResponse,
)
from earnix_elevate.clients.data.models.dataset_version_usage import (
    DatasetVersionUsage as DatasetVersionUsage,
)
from earnix_elevate.clients.data.models.datasets_response import (
    DatasetsResponse as DatasetsResponse,
)
from earnix_elevate.clients.data.models.execute_recipe_request import (
    ExecuteRecipeRequest as ExecuteRecipeRequest,
)
from earnix_elevate.clients.data.models.export_part_result_pair_response import (
    ExportPartResultPairResponse as ExportPartResultPairResponse,
)
from earnix_elevate.clients.data.models.export_s3_job_status_response import (
    ExportS3JobStatusResponse as ExportS3JobStatusResponse,
)
from earnix_elevate.clients.data.models.export_s3_part_job_status_response import (
    ExportS3PartJobStatusResponse as ExportS3PartJobStatusResponse,
)
from earnix_elevate.clients.data.models.export_s3_part_request import (
    ExportS3PartRequest as ExportS3PartRequest,
)
from earnix_elevate.clients.data.models.export_s3_part_response import (
    ExportS3PartResponse as ExportS3PartResponse,
)
from earnix_elevate.clients.data.models.export_s3_request import (
    ExportS3Request as ExportS3Request,
)
from earnix_elevate.clients.data.models.export_s3_response import (
    ExportS3Response as ExportS3Response,
)
from earnix_elevate.clients.data.models.export_s3_status_response import (
    ExportS3StatusResponse as ExportS3StatusResponse,
)
from earnix_elevate.clients.data.models.job_error import JobError as JobError
from earnix_elevate.clients.data.models.job_execution import (
    JobExecution as JobExecution,
)
from earnix_elevate.clients.data.models.job_progress import JobProgress as JobProgress
from earnix_elevate.clients.data.models.job_stage import JobStage as JobStage
from earnix_elevate.clients.data.models.job_status import JobStatus as JobStatus
from earnix_elevate.clients.data.models.lean_transformation_graph_response import (
    LeanTransformationGraphResponse as LeanTransformationGraphResponse,
)
from earnix_elevate.clients.data.models.list_query import ListQuery as ListQuery
from earnix_elevate.clients.data.models.metadata import Metadata as Metadata
from earnix_elevate.clients.data.models.problem_detail import (
    ProblemDetail as ProblemDetail,
)
from earnix_elevate.clients.data.models.recipe_code_response import (
    RecipeCodeResponse as RecipeCodeResponse,
)
from earnix_elevate.clients.data.models.recipe_response import (
    RecipeResponse as RecipeResponse,
)
from earnix_elevate.clients.data.models.recipe_status_response import (
    RecipeStatusResponse as RecipeStatusResponse,
)
from earnix_elevate.clients.data.models.recipe_version import (
    RecipeVersion as RecipeVersion,
)
from earnix_elevate.clients.data.models.recipe_version_response import (
    RecipeVersionResponse as RecipeVersionResponse,
)
from earnix_elevate.clients.data.models.recipes_response import (
    RecipesResponse as RecipesResponse,
)
from earnix_elevate.clients.data.models.schema_analysis_status_response import (
    SchemaAnalysisStatusResponse as SchemaAnalysisStatusResponse,
)
from earnix_elevate.clients.data.models.sink_node_item import (
    SinkNodeItem as SinkNodeItem,
)
from earnix_elevate.clients.data.models.sink_nodes_response import (
    SinkNodesResponse as SinkNodesResponse,
)
from earnix_elevate.clients.data.models.source_node_definition import (
    SourceNodeDefinition as SourceNodeDefinition,
)
from earnix_elevate.clients.data.models.transformation_graph_response import (
    TransformationGraphResponse as TransformationGraphResponse,
)
from earnix_elevate.clients.data.models.transformation_graph_wrapper_response import (
    TransformationGraphWrapperResponse as TransformationGraphWrapperResponse,
)
from earnix_elevate.clients.data.models.update_data_table_request import (
    UpdateDataTableRequest as UpdateDataTableRequest,
)
from earnix_elevate.clients.data.models.update_dataset_data_table_node_request import (
    UpdateDatasetDataTableNodeRequest as UpdateDatasetDataTableNodeRequest,
)
from earnix_elevate.clients.data.models.update_dataset_node_request import (
    UpdateDatasetNodeRequest as UpdateDatasetNodeRequest,
)
from earnix_elevate.clients.data.models.update_dataset_recipe_node_request import (
    UpdateDatasetRecipeNodeRequest as UpdateDatasetRecipeNodeRequest,
)
from earnix_elevate.clients.data.models.update_dataset_request import (
    UpdateDatasetRequest as UpdateDatasetRequest,
)
from earnix_elevate.clients.data.models.update_recipe_request import (
    UpdateRecipeRequest as UpdateRecipeRequest,
)
from earnix_elevate.clients.data.models.update_recipe_version_request import (
    UpdateRecipeVersionRequest as UpdateRecipeVersionRequest,
)
from earnix_elevate.clients.data.models.user import User as User
from earnix_elevate.clients.data.models.user_message_request import (
    UserMessageRequest as UserMessageRequest,
)



from ..clients.data import (
    ApiClient,
    Configuration,
    DatasetServiceApi,
    DataTableServiceApi,
    ExportJobServiceApi,
    RecipeServiceApi,
)
from .common import BaseElevateClient, BaseElevateService


class DataClient(BaseElevateClient, ApiClient):
    _route = "/api/data"
    _conf_class = Configuration


class DataTableService(BaseElevateService, DataTableServiceApi):
    _client_class = DataClient


class DatasetService(BaseElevateService, DatasetServiceApi):
    _client_class = DataClient


class ExportJobService(BaseElevateService, ExportJobServiceApi):
    _client_class = DataClient


class RecipeService(BaseElevateService, RecipeServiceApi):
    _client_class = DataClient



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from datetime import datetime
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictStr, validator


class ConversationMessageResponse(BaseModel):
    """
    `ConversationMessageResponse`

    Represents a single message within a conversation in the AI assistant service, containing the message content, author, and timestamp
    """

    conversation_id: Optional[StrictStr] = Field(
        default=None,
        alias="conversationId",
        description="Unique identifier for the containing conversation",
    )
    type: Optional[StrictStr] = Field(
        default=None, description="Type of the message in LLM chat"
    )
    content: Optional[StrictStr] = Field(
        default=None, description="Content of the message"
    )
    timestamp: Optional[datetime] = Field(
        default=None, description="Date and time when the message was sent"
    )
    __properties = ["conversationId", "type", "content", "timestamp"]

    @validator("type")
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (
            "SYSTEM",
            "USER",
            "ASSISTANT",
            "TOOL",
        ):
            raise ValueError(
                "must be one of enum values ('SYSTEM', 'USER', 'ASSISTANT', 'TOOL')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ConversationMessageResponse:
        """Create an instance of ConversationMessageResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ConversationMessageResponse:
        """Create an instance of ConversationMessageResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ConversationMessageResponse.parse_obj(obj)

        _obj = ConversationMessageResponse.parse_obj(
            {
                "conversation_id": obj.get("conversationId"),
                "type": obj.get("type"),
                "content": obj.get("content"),
                "timestamp": obj.get("timestamp"),
            }
        )
        return _obj
